@@ -1,7 +1,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x03060400
+#define LIBXL_VERSION 0x03070000
 
 #ifdef _UNICODE
 
@@ -71,10 +71,15 @@
     #define xlSheetWriteBlank xlSheetWriteBlankW
     #define xlSheetReadFormula xlSheetReadFormulaW
     #define xlSheetWriteFormula xlSheetWriteFormulaW
+    #define xlSheetWriteFormulaNum xlSheetWriteFormulaNumW
+    #define xlSheetWriteFormulaStr xlSheetWriteFormulaStrW
+    #define xlSheetWriteFormulaBool xlSheetWriteFormulaBoolW
     #define xlSheetReadComment xlSheetReadCommentW
     #define xlSheetWriteComment xlSheetWriteCommentW
+    #define xlSheetRemoveComment xlSheetRemoveCommentW
     #define xlSheetIsDate xlSheetIsDateW
     #define xlSheetReadError xlSheetReadErrorW
+    #define xlSheetWriteError xlSheetWriteErrorW
     #define xlSheetColWidth xlSheetColWidthW
     #define xlSheetRowHeight xlSheetRowHeightW
     #define xlSheetSetCol xlSheetSetColW
@@ -164,10 +169,15 @@
     #define xlSheetDelNamedRange xlSheetDelNamedRangeW
     #define xlSheetNamedRangeSize xlSheetNamedRangeSizeW
     #define xlSheetNamedRange xlSheetNamedRangeW
+    #define xlSheetTableSize xlSheetTableSizeW
+    #define xlSheetTable xlSheetTableW
     #define xlSheetHyperlinkSize xlSheetHyperlinkSizeW
     #define xlSheetHyperlink xlSheetHyperlinkW
     #define xlSheetDelHyperlink xlSheetDelHyperlinkW
     #define xlSheetAddHyperlink xlSheetAddHyperlinkW
+    #define xlSheetAutoFilter xlSheetAutoFilterW
+    #define xlSheetApplyFilter xlSheetApplyFilterW
+    #define xlSheetRemoveFilter xlSheetRemoveFilterW
     #define xlSheetName xlSheetNameW
     #define xlSheetSetName xlSheetSetNameW
     #define xlSheetProtect xlSheetProtectW
@@ -181,6 +191,9 @@
     #define xlSheetSetAutoFitArea xlSheetSetAutoFitAreaW
     #define xlSheetAddrToRowCol xlSheetAddrToRowColW
     #define xlSheetRowColToAddr xlSheetRowColToAddrW
+    #define xlSheetSetTabColor xlSheetSetTabColorW
+    #define xlSheetSetTabRgbColor xlSheetSetTabRgbColorW
+    #define xlSheetAddIgnoredError addIgnoredErrorW
 
     #define xlFontSize xlFontSizeW
     #define xlFontSetSize xlFontSetSizeW
@@ -250,6 +263,26 @@
     #define xlFormatHidden xlFormatHiddenW
     #define xlFormatSetHidden xlFormatSetHiddenW
 
+    #define xlAutoFilterGetRef xlAutoFilterGetRefW
+    #define xlAutoFilterSetRef xlAutoFilterSetRefW
+    #define xlAutoFilterColumn xlAutoFilterColumnW
+    #define xlAutoFilterColumnSize xlAutoFilterColumnSizeW
+    #define xlAutoFilterColumnByIndex xlAutoFilterColumnByIndexW
+    #define xlAutoFilterGetSortRange xlAutoFilterGetSortRangeW
+    #define xlAutoFilterGetSort xlAutoFilterGetSortW
+    #define xlAutoFilterSetSort xlAutoFilterSetSortW
+
+    #define xlFilterColumnIndex xlFilterColumnIndexW
+    #define xlFilterColumnFilterType xlFilterColumnFilterTypeW
+    #define xlFilterColumnFilterSize xlFilterColumnFilterSizeW
+    #define xlFilterColumnFilter xlFilterColumnFilterW
+    #define xlFilterColumnAddFilter xlFilterColumnAddFilterW
+    #define xlFilterColumnGetTop10 xlFilterColumnGetTop10W
+    #define xlFilterColumnSetTop10 xlFilterColumnSetTop10W
+    #define xlFilterColumnGetCustomFilter xlFilterColumnGetCustomFilterW
+    #define xlFilterColumnSetCustomFilter xlFilterColumnSetCustomFilterW
+    #define xlFilterColumnClear xlFilterColumnClearW
+
 #else
 
     #include "BookA.h"
@@ -318,10 +351,15 @@
     #define xlSheetWriteBlank xlSheetWriteBlankA
     #define xlSheetReadFormula xlSheetReadFormulaA
     #define xlSheetWriteFormula xlSheetWriteFormulaA
+    #define xlSheetWriteFormulaNum xlSheetWriteFormulaNumA
+    #define xlSheetWriteFormulaStr xlSheetWriteFormulaStrA
+    #define xlSheetWriteFormulaBool xlSheetWriteFormulaBoolA
     #define xlSheetReadComment xlSheetReadCommentA
     #define xlSheetWriteComment xlSheetWriteCommentA
+    #define xlSheetRemoveComment xlSheetRemoveCommentA
     #define xlSheetIsDate xlSheetIsDateA
     #define xlSheetReadError xlSheetReadErrorA
+    #define xlSheetWriteError xlSheetWriteErrorA
     #define xlSheetColWidth xlSheetColWidthA
     #define xlSheetRowHeight xlSheetRowHeightA
     #define xlSheetSetCol xlSheetSetColA
@@ -411,10 +449,15 @@
     #define xlSheetDelNamedRange xlSheetDelNamedRangeA
     #define xlSheetNamedRangeSize xlSheetNamedRangeSizeA
     #define xlSheetNamedRange xlSheetNamedRangeA
+    #define xlSheetTableSize xlSheetTableSizeA
+    #define xlSheetTable xlSheetTableA
     #define xlSheetHyperlinkSize xlSheetHyperlinkSizeA
     #define xlSheetHyperlink xlSheetHyperlinkA
     #define xlSheetDelHyperlink xlSheetDelHyperlinkA
     #define xlSheetAddHyperlink xlSheetAddHyperlinkA
+    #define xlSheetAutoFilter xlSheetAutoFilterA
+    #define xlSheetApplyFilter xlSheetApplyFilterA
+    #define xlSheetRemoveFilter xlSheetRemoveFilterA
     #define xlSheetName xlSheetNameA
     #define xlSheetSetName xlSheetSetNameA
     #define xlSheetProtect xlSheetProtectA
@@ -428,6 +471,9 @@
     #define xlSheetSetAutoFitArea xlSheetSetAutoFitAreaA
     #define xlSheetAddrToRowCol xlSheetAddrToRowColA
     #define xlSheetRowColToAddr xlSheetRowColToAddrA
+    #define xlSheetSetTabColor xlSheetSetTabColorA
+    #define xlSheetSetTabRgbColor xlSheetSetTabRgbColorA
+    #define xlSheetAddIgnoredError addIgnoredErrorA
 
     #define xlFontSize xlFontSizeA
     #define xlFontSetSize xlFontSetSizeA
@@ -497,6 +543,26 @@
     #define xlFormatHidden xlFormatHiddenA
     #define xlFormatSetHidden xlFormatSetHiddenA
 
+    #define xlAutoFilterGetRef xlAutoFilterGetRefA
+    #define xlAutoFilterSetRef xlAutoFilterSetRefA
+    #define xlAutoFilterColumn xlAutoFilterColumnA
+    #define xlAutoFilterColumnSize xlAutoFilterColumnSizeA
+    #define xlAutoFilterColumnByIndex xlAutoFilterColumnByIndexA
+    #define xlAutoFilterGetSortRange xlAutoFilterGetSortRangeA
+    #define xlAutoFilterGetSort xlAutoFilterGetSortA
+    #define xlAutoFilterSetSort xlAutoFilterSetSortA
+
+    #define xlFilterColumnIndex xlFilterColumnIndexA
+    #define xlFilterColumnFilterType xlFilterColumnFilterTypeA
+    #define xlFilterColumnFilterSize xlFilterColumnFilterSizeA
+    #define xlFilterColumnFilter xlFilterColumnFilterA
+    #define xlFilterColumnAddFilter xlFilterColumnAddFilterA
+    #define xlFilterColumnGetTop10 xlFilterColumnGetTop10A
+    #define xlFilterColumnSetTop10 xlFilterColumnSetTop10A
+    #define xlFilterColumnGetCustomFilter xlFilterColumnGetCustomFilterA
+    #define xlFilterColumnSetCustomFilter xlFilterColumnSetCustomFilterA
+    #define xlFilterColumnClear xlFilterColumnClearA
+
 #endif
 
 #endif
